

/* 
 *************************************
 * <!-- AJAX -->
 *************************************
 */
theme = ( function ( theme, $, window, document ) {
    'use strict';
   
   
    var documentReady = function( $ ) {
		
		/*
		 * Apply some original scripts
		 *
		 * @return {void}  - The constructor.
		 */
		
		
		function applyOriginalSomeScripts() {
			
			theme.commonHeight.pageLoaded(); //Common Height
			theme.accordion.documentReady($); //Accordion
			
			
		}

		
		/*
		 * Apply all the original scripts
		 *
		 * @return {void}  - The constructor.
		 */
		
		
		function applyOriginalAllScripts() {
			
			
			var scipts_pageLoaded    = theme.components.pageLoaded,
				scipts_documentReady = theme.components.documentReady;
			
			
			for ( var i = 0; i < scipts_pageLoaded.length; i++ ) {
			     scipts_pageLoaded[i]();
			}
			for ( var j = 0; j < scipts_documentReady.length; j++ ) {
			     scipts_documentReady[j]( $ );
			}	
		
			
			
		}
	
		
		
		
	};
	
		
    theme.ajax = {
        documentReady : documentReady        
    };

    theme.components.documentReady.push( documentReady );
    return theme;

}( theme, jQuery, window, document ) );


